## Changelog

### 0.2.0

**Commit Delta**: [Change from 0.1.3 release](https://github.com/plus3it/watchmaker/compare/0.1.3...0.2.0)

**Released**: 2020.03.04

**Summary**:

*   Allow comparison between prerelease and dev releases (e.g., `1.0.dev0`) and final releases (e.g., `1.0`)

### 0.1.3

**Commit Delta**: [Change from 0.1.2 release](https://github.com/plus3it/watchmaker/compare/0.1.2...0.1.3)

**Released**: 2020.01.28

**Summary**:

*   Update dependencies
*   Update Python compatibility versions in PyPI/wheel package

### 0.1.2

**Commit Delta**: [Change from 0.1.1 release](https://github.com/plus3it/watchmaker/compare/0.1.1...0.1.2)

**Released**: 2019.10.24

**Summary**:

*   Improve compatibility with Py2.6

### 0.1.1

**Commit Delta**: [Change from 0.1.0 release](https://github.com/plus3it/watchmaker/compare/0.1.0...0.1.1)

**Released**: 2019.10.24

**Summary**:

*   Minor CI changes
*   Add documentation

### 0.1.0

**Commit Delta**: [Change from 0.0.0 release](https://github.com/plus3it/watchmaker/compare/0.0.0...0.1.0)

**Released**: 2019.10.22

**Summary**:

*   Initial release
